@@ -46,24 +46,33 @@ class WorkflowExecutionService:
         )
 
     def create(
-        self, user_input: Optional[str] = None, file_name: Optional[str] = None
+        self,
+        user_input: Optional[str] = None,
+        file_name: Optional[str] = None,
+        propagate_headers: bool = False,
+        headers: Optional[dict[str, str]] = None,
     ) -> dict:
         """Create a new workflow execution.
 
         Args:
             user_input: Optional input data for the workflow execution.
             file_name: Optional file name associated with the workflow execution.
+            propagate_headers: Enable propagation of X-* HTTP headers to MCP servers.
+            headers: Optional additional HTTP headers (e.g., X-* for MCP propagation)
 
         Returns:
             dict: Created workflow execution details
         """
         payload = WorkflowExecutionCreateRequest(
-            user_input=user_input, file_name=file_name
+            user_input=user_input,
+            file_name=file_name,
+            propagate_headers=propagate_headers,
         )
         return self._api.post(
             f"/v1/workflows/{self._workflow_id}/executions",
             dict,
             json_data=payload.model_dump(),
+            extra_headers=headers,
         )
 
     def get(self, execution_id: str) -> WorkflowExecution:
@@ -108,17 +117,30 @@ class WorkflowExecutionService:
             f"/v1/workflows/{self._workflow_id}/executions/{execution_id}/abort", dict
         )
 
-    def resume(self, execution_id: str) -> dict:
+    def resume(
+        self,
+        execution_id: str,
+        propagate_headers: bool = False,
+        headers: Optional[dict[str, str]] = None,
+    ) -> dict:
         """Resume an interrupted workflow execution.
 
         Args:
             execution_id: ID of the execution to resume
+            propagate_headers: Enable propagation of X-* HTTP headers to MCP servers.
+            headers: Optional additional HTTP headers (e.g., X-* for MCP propagation)
 
         Returns:
             dict: Updated workflow execution details
         """
+        params = {"propagate_headers": propagate_headers}
+        # Empty body per API; passing empty dict to satisfy typing
         return self._api.put(
-            f"/v1/workflows/{self._workflow_id}/executions/{execution_id}/resume", dict
+            f"/v1/workflows/{self._workflow_id}/executions/{execution_id}/resume",
+            dict,
+            json_data={},
+            params=params,
+            extra_headers=headers,
         )
 
     def get_thoughts(
